from django.contrib import admin

from apis_core.collections.models import SkosCollection, SkosCollectionContentObject

admin.site.register(SkosCollection)
admin.site.register(SkosCollectionContentObject)
