{% block footer %}
  <footer class="border-top p-2 bg-light">
    <div class="row m-0">
      <div class="col text-start">

        {% block footer-left %}
          {% include "partials/footer-left.html" %}
        {% endblock footer-left %}

      </div>
      <div class="col text-center">

        {% block footer-center %}
        {% endblock footer-center %}

      </div>
      <div class="col text-end">

        {% block footer-right %}
          {% block imprint %}
          {% endblock imprint %}
        {% endblock footer-right %}

      </div>
    </div>
  </footer>
{% endblock footer %}
