{% extends "apis_core/apis_entities/abstractentity_detail.html" %}

{% block col-one %}
  {% block relations-include %}
    {% include "relations/list_relations.html" %}
  {% endblock relations-include %}

  {{ block.super }}
{% endblock col-one %}
