# Generated by Django 4.1.10 on 2023-09-06 07:04

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_metainfo", "0004_auto_20230310_0804"),
    ]

    operations = [
        migrations.DeleteModel(
            name="UriCandidate",
        ),
    ]
