# Generated by Django 4.2.10 on 2024-03-07 08:39

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("apis_metainfo", "0009_remove_collection_collection_type"),
    ]

    operations = [
        migrations.RenameField(
            model_name="rootobject",
            old_name="name",
            new_name="deprecated_name",
        ),
    ]
