{% extends "generic/genericmodel_confirm_delete.html" %}
{% load i18n %}

{% block content %}
  <div class="container">
    <div class="text-center">
      <form action="" method="post">
        {% csrf_token %}
        <h3>{% translate "Confirm deletion of" %}:</h3>
        <p>{{ object|urlize }},</p>
        {% blocktranslate trimmed with url=object.content_object.get_absolute_url type=object.content_object.get_verbose_name target=object.content_object %}
          <p>which is linked to</p>
          <p>
            <a href="{{ url }}">{{ type }}: "{{ target }}"</a>
          </p>
        {% endblocktranslate %}
        <input class="btn btn-danger"
               type="submit"
               value="{% translate "Yes, delete" %}" />
      </form>
    </div>
  </div>
{% endblock content %}
